==> eam-wshub-proxyclient-11.4-8-sources.jar: net/datastream/schemas/mp_entities/casemanagementtask_001/TrackingDetails.java <==

package net.datastream.schemas.mp_entities.casemanagementtask_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.Employee_Type;
import net.datastream.schemas.mp_fields.PERSONID_Type;
import net.datastream.schemas.mp_fields.PLANNEDDURATION_Type;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RESPONSIBLEROLE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PERSONRESPONSIBLE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EMAIL" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASSIGNEDTOROLE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASSIGNEDTO" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASSIGNEDTOEMAIL" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PLANNEDDURATION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SCHEDULEDSTARTDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SCHEDULEDENDDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REQUESTEDSTART" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REQUESTEDEND" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FIRMDATES" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}READYTOSTART" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STARTED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STARTDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COMPLETED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PERCENTCOMPLETED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COMPLETEDDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NOTIFYCOMPLETE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NOTIFYREADYTOSTART" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "responsiblerole",
    "personresponsible",
    "email",
    "assignedtorole",
    "assignedto",
    "assignedtoemail",
    "plannedduration",
    "scheduledstartdate",
    "scheduledenddate",
    "requestedstart",
    "requestedend",
    "firmdates",
    "readytostart",
    "started",
    "startdate",
    "completed",
    "percentcompleted",
    "completeddate",
    "notifycomplete",
    "notifyreadytostart"
})
@XmlRootElement(name = "TrackingDetails")
public class TrackingDetails {

    @XmlElement(name = "RESPONSIBLEROLE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String responsiblerole;
    @XmlElement(name = "PERSONRESPONSIBLE", namespace = "http://schemas.datastream.net/MP_fields")
    protected Employee_Type personresponsible;
    @XmlElement(name = "EMAIL", namespace = "http://schemas.datastream.net/MP_fields")
    protected String email;
    @XmlElement(name = "ASSIGNEDTOROLE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String assignedtorole;
    @XmlElement(name = "ASSIGNEDTO", namespace = "http://schemas.datastream.net/MP_fields")
    protected PERSONID_Type assignedto;
    @XmlElement(name = "ASSIGNEDTOEMAIL", namespace = "http://schemas.datastream.net/MP_fields")
    protected String assignedtoemail;
    @XmlElement(name = "PLANNEDDURATION", namespace = "http://schemas.datastream.net/MP_fields")
    protected PLANNEDDURATION_Type plannedduration;
    @XmlElement(name = "SCHEDULEDSTARTDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME scheduledstartdate;
    @XmlElement(name = "SCHEDULEDENDDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME scheduledenddate;
    @XmlElement(name = "REQUESTEDSTART", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME requestedstart;
    @XmlElement(name = "REQUESTEDEND", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME requestedend;
    @XmlElement(name = "FIRMDATES", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String firmdates;
    @XmlElement(name = "READYTOSTART", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String readytostart;
    @XmlElement(name = "STARTED", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String started;
    @XmlElement(name = "STARTDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME startdate;
    @XmlElement(name = "COMPLETED", namespace = "http://schemas.datastream.net/MP_fields")
    protected String completed;
    @XmlElement(name = "PERCENTCOMPLETED", namespace = "http://schemas.datastream.net/MP_fields")
    protected Long percentcompleted;
    @XmlElement(name = "COMPLETEDDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME completeddate;
    @XmlElement(name = "NOTIFYCOMPLETE", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String notifycomplete;
    @XmlElement(name = "NOTIFYREADYTOSTART", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String notifyreadytostart;

    /**
     * Obtient la valeur de la propriété responsiblerole.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRESPONSIBLEROLE() {
        return responsiblerole;
    }

    /**
     * Définit la valeur de la propriété responsiblerole.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRESPONSIBLEROLE(String value) {
        this.responsiblerole = value;
    }

    /**
     * Obtient la valeur de la propriété personresponsible.
     * 
     * @return
     *     possible object is
     *     {@link Employee_Type }
     *     
     */
    public Employee_Type getPERSONRESPONSIBLE() {
        return personresponsible;
    }

    /**
     * Définit la valeur de la propriété personresponsible.
     * 
     * @param value
     *     allowed object is
     *     {@link Employee_Type }
     *     
     */
    public void setPERSONRESPONSIBLE(Employee_Type value) {
        this.personresponsible = value;
    }

    /**
     * Obtient la valeur de la propriété email.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEMAIL() {
        return email;
    }

    /**
     * Définit la valeur de la propriété email.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEMAIL(String value) {
        this.email = value;
    }

    /**
     * Obtient la valeur de la propriété assignedtorole.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getASSIGNEDTOROLE() {
        return assignedtorole;
    }

    /**
     * Définit la valeur de la propriété assignedtorole.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setASSIGNEDTOROLE(String value) {
        this.assignedtorole = value;
    }

    /**
     * Obtient la valeur de la propriété assignedto.
     * 
     * @return
     *     possible object is
     *     {@link PERSONID_Type }
     *     
     */
    public PERSONID_Type getASSIGNEDTO() {
        return assignedto;
    }

    /**
     * Définit la valeur de la propriété assignedto.
     * 
     * @param value
     *     allowed object is
     *     {@link PERSONID_Type }
     *     
     */
    public void setASSIGNEDTO(PERSONID_Type value) {
        this.assignedto = value;
    }

    /**
     * Obtient la valeur de la propriété assignedtoemail.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getASSIGNEDTOEMAIL() {
        return assignedtoemail;
    }

    /**
     * Définit la valeur de la propriété assignedtoemail.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setASSIGNEDTOEMAIL(String value) {
        this.assignedtoemail = value;
    }

    /**
     * Obtient la valeur de la propriété plannedduration.
     * 
     * @return
     *     possible object is
     *     {@link PLANNEDDURATION_Type }
     *     
     */
    public PLANNEDDURATION_Type getPLANNEDDURATION() {
        return plannedduration;
    }

    /**
     * Définit la valeur de la propriété plannedduration.
     * 
     * @param value
     *     allowed object is
     *     {@link PLANNEDDURATION_Type }
     *     
     */
    public void setPLANNEDDURATION(PLANNEDDURATION_Type value) {
        this.plannedduration = value;
    }

    /**
     * Obtient la valeur de la propriété scheduledstartdate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getSCHEDULEDSTARTDATE() {
        return scheduledstartdate;
    }

    /**
     * Définit la valeur de la propriété scheduledstartdate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setSCHEDULEDSTARTDATE(DATETIME value) {
        this.scheduledstartdate = value;
    }

    /**
     * Obtient la valeur de la propriété scheduledenddate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getSCHEDULEDENDDATE() {
        return scheduledenddate;
    }

    /**
     * Définit la valeur de la propriété scheduledenddate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setSCHEDULEDENDDATE(DATETIME value) {
        this.scheduledenddate = value;
    }

    /**
     * Obtient la valeur de la propriété requestedstart.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getREQUESTEDSTART() {
        return requestedstart;
    }

    /**
     * Définit la valeur de la propriété requestedstart.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setREQUESTEDSTART(DATETIME value) {
        this.requestedstart = value;
    }

    /**
     * Obtient la valeur de la propriété requestedend.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getREQUESTEDEND() {
        return requestedend;
    }

    /**
     * Définit la valeur de la propriété requestedend.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setREQUESTEDEND(DATETIME value) {
        this.requestedend = value;
    }

    /**
     * Obtient la valeur de la propriété firmdates.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFIRMDATES() {
        return firmdates;
    }

    /**
     * Définit la valeur de la propriété firmdates.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFIRMDATES(String value) {
        this.firmdates = value;
    }

    /**
     * Obtient la valeur de la propriété readytostart.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getREADYTOSTART() {
        return readytostart;
    }

    /**
     * Définit la valeur de la propriété readytostart.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setREADYTOSTART(String value) {
        this.readytostart = value;
    }

    /**
     * Obtient la valeur de la propriété started.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSTARTED() {
        return started;
    }

    /**
     * Définit la valeur de la propriété started.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSTARTED(String value) {
        this.started = value;
    }

    /**
     * Obtient la valeur de la propriété startdate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getSTARTDATE() {
        return startdate;
    }

    /**
     * Définit la valeur de la propriété startdate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setSTARTDATE(DATETIME value) {
        this.startdate = value;
    }

    /**
     * Obtient la valeur de la propriété completed.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOMPLETED() {
        return completed;
    }

    /**
     * Définit la valeur de la propriété completed.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOMPLETED(String value) {
        this.completed = value;
    }

    /**
     * Obtient la valeur de la propriété percentcompleted.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getPERCENTCOMPLETED() {
        return percentcompleted;
    }

    /**
     * Définit la valeur de la propriété percentcompleted.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setPERCENTCOMPLETED(Long value) {
        this.percentcompleted = value;
    }

    /**
     * Obtient la valeur de la propriété completeddate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getCOMPLETEDDATE() {
        return completeddate;
    }

    /**
     * Définit la valeur de la propriété completeddate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setCOMPLETEDDATE(DATETIME value) {
        this.completeddate = value;
    }

    /**
     * Obtient la valeur de la propriété notifycomplete.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getNOTIFYCOMPLETE() {
        return notifycomplete;
    }

    /**
     * Définit la valeur de la propriété notifycomplete.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setNOTIFYCOMPLETE(String value) {
        this.notifycomplete = value;
    }

    /**
     * Obtient la valeur de la propriété notifyreadytostart.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getNOTIFYREADYTOSTART() {
        return notifyreadytostart;
    }

    /**
     * Définit la valeur de la propriété notifyreadytostart.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setNOTIFYREADYTOSTART(String value) {
        this.notifyreadytostart = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_entities/casemanagementtask_001/TrackingDetails.java <==

package net.datastream.schemas.mp_entities.casemanagementtask_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.Employee_Type;
import net.datastream.schemas.mp_fields.PERSONID_Type;
import net.datastream.schemas.mp_fields.PLANNEDDURATION_Type;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RESPONSIBLEROLE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PERSONRESPONSIBLE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EMAIL" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASSIGNEDTOROLE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASSIGNEDTO" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASSIGNEDTOEMAIL" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PLANNEDDURATION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SCHEDULEDSTARTDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SCHEDULEDENDDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REQUESTEDSTART" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REQUESTEDEND" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FIRMDATES" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}READYTOSTART" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STARTED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STARTDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COMPLETED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PERCENTCOMPLETED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COMPLETEDDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NOTIFYCOMPLETE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NOTIFYREADYTOSTART" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "responsiblerole",
    "personresponsible",
    "email",
    "assignedtorole",
    "assignedto",
    "assignedtoemail",
    "plannedduration",
    "scheduledstartdate",
    "scheduledenddate",
    "requestedstart",
    "requestedend",
    "firmdates",
    "readytostart",
    "started",
    "startdate",
    "completed",
    "percentcompleted",
    "completeddate",
    "notifycomplete",
    "notifyreadytostart"
})
@XmlRootElement(name = "TrackingDetails")
public class TrackingDetails {

    @XmlElement(name = "RESPONSIBLEROLE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String responsiblerole;
    @XmlElement(name = "PERSONRESPONSIBLE", namespace = "http://schemas.datastream.net/MP_fields")
    protected Employee_Type personresponsible;
    @XmlElement(name = "EMAIL", namespace = "http://schemas.datastream.net/MP_fields")
    protected String email;
    @XmlElement(name = "ASSIGNEDTOROLE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String assignedtorole;
    @XmlElement(name = "ASSIGNEDTO", namespace = "http://schemas.datastream.net/MP_fields")
    protected PERSONID_Type assignedto;
    @XmlElement(name = "ASSIGNEDTOEMAIL", namespace = "http://schemas.datastream.net/MP_fields")
    protected String assignedtoemail;
    @XmlElement(name = "PLANNEDDURATION", namespace = "http://schemas.datastream.net/MP_fields")
    protected PLANNEDDURATION_Type plannedduration;
    @XmlElement(name = "SCHEDULEDSTARTDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME scheduledstartdate;
    @XmlElement(name = "SCHEDULEDENDDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME scheduledenddate;
    @XmlElement(name = "REQUESTEDSTART", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME requestedstart;
    @XmlElement(name = "REQUESTEDEND", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME requestedend;
    @XmlElement(name = "FIRMDATES", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String firmdates;
    @XmlElement(name = "READYTOSTART", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String readytostart;
    @XmlElement(name = "STARTED", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String started;
    @XmlElement(name = "STARTDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME startdate;
    @XmlElement(name = "COMPLETED", namespace = "http://schemas.datastream.net/MP_fields")
    protected String completed;
    @XmlElement(name = "PERCENTCOMPLETED", namespace = "http://schemas.datastream.net/MP_fields")
    protected Long percentcompleted;
    @XmlElement(name = "COMPLETEDDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME completeddate;
    @XmlElement(name = "NOTIFYCOMPLETE", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String notifycomplete;
    @XmlElement(name = "NOTIFYREADYTOSTART", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String notifyreadytostart;

    /**
     * Gets the value of the responsiblerole property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRESPONSIBLEROLE() {
        return responsiblerole;
    }

    /**
     * Sets the value of the responsiblerole property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRESPONSIBLEROLE(String value) {
        this.responsiblerole = value;
    }

    /**
     * Gets the value of the personresponsible property.
     * 
     * @return
     *     possible object is
     *     {@link Employee_Type }
     *     
     */
    public Employee_Type getPERSONRESPONSIBLE() {
        return personresponsible;
    }

    /**
     * Sets the value of the personresponsible property.
     * 
     * @param value
     *     allowed object is
     *     {@link Employee_Type }
     *     
     */
    public void setPERSONRESPONSIBLE(Employee_Type value) {
        this.personresponsible = value;
    }

    /**
     * Gets the value of the email property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEMAIL() {
        return email;
    }

    /**
     * Sets the value of the email property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEMAIL(String value) {
        this.email = value;
    }

    /**
     * Gets the value of the assignedtorole property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getASSIGNEDTOROLE() {
        return assignedtorole;
    }

    /**
     * Sets the value of the assignedtorole property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setASSIGNEDTOROLE(String value) {
        this.assignedtorole = value;
    }

    /**
     * Gets the value of the assignedto property.
     * 
     * @return
     *     possible object is
     *     {@link PERSONID_Type }
     *     
     */
    public PERSONID_Type getASSIGNEDTO() {
        return assignedto;
    }

    /**
     * Sets the value of the assignedto property.
     * 
     * @param value
     *     allowed object is
     *     {@link PERSONID_Type }
     *     
     */
    public void setASSIGNEDTO(PERSONID_Type value) {
        this.assignedto = value;
    }

    /**
     * Gets the value of the assignedtoemail property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getASSIGNEDTOEMAIL() {
        return assignedtoemail;
    }

    /**
     * Sets the value of the assignedtoemail property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setASSIGNEDTOEMAIL(String value) {
        this.assignedtoemail = value;
    }

    /**
     * Gets the value of the plannedduration property.
     * 
     * @return
     *     possible object is
     *     {@link PLANNEDDURATION_Type }
     *     
     */
    public PLANNEDDURATION_Type getPLANNEDDURATION() {
        return plannedduration;
    }

    /**
     * Sets the value of the plannedduration property.
     * 
     * @param value
     *     allowed object is
     *     {@link PLANNEDDURATION_Type }
     *     
     */
    public void setPLANNEDDURATION(PLANNEDDURATION_Type value) {
        this.plannedduration = value;
    }

    /**
     * Gets the value of the scheduledstartdate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getSCHEDULEDSTARTDATE() {
        return scheduledstartdate;
    }

    /**
     * Sets the value of the scheduledstartdate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setSCHEDULEDSTARTDATE(DATETIME value) {
        this.scheduledstartdate = value;
    }

    /**
     * Gets the value of the scheduledenddate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getSCHEDULEDENDDATE() {
        return scheduledenddate;
    }

    /**
     * Sets the value of the scheduledenddate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setSCHEDULEDENDDATE(DATETIME value) {
        this.scheduledenddate = value;
    }

    /**
     * Gets the value of the requestedstart property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getREQUESTEDSTART() {
        return requestedstart;
    }

    /**
     * Sets the value of the requestedstart property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setREQUESTEDSTART(DATETIME value) {
        this.requestedstart = value;
    }

    /**
     * Gets the value of the requestedend property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getREQUESTEDEND() {
        return requestedend;
    }

    /**
     * Sets the value of the requestedend property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setREQUESTEDEND(DATETIME value) {
        this.requestedend = value;
    }

    /**
     * Gets the value of the firmdates property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFIRMDATES() {
        return firmdates;
    }

    /**
     * Sets the value of the firmdates property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFIRMDATES(String value) {
        this.firmdates = value;
    }

    /**
     * Gets the value of the readytostart property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getREADYTOSTART() {
        return readytostart;
    }

    /**
     * Sets the value of the readytostart property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setREADYTOSTART(String value) {
        this.readytostart = value;
    }

    /**
     * Gets the value of the started property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSTARTED() {
        return started;
    }

    /**
     * Sets the value of the started property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSTARTED(String value) {
        this.started = value;
    }

    /**
     * Gets the value of the startdate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getSTARTDATE() {
        return startdate;
    }

    /**
     * Sets the value of the startdate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setSTARTDATE(DATETIME value) {
        this.startdate = value;
    }

    /**
     * Gets the value of the completed property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOMPLETED() {
        return completed;
    }

    /**
     * Sets the value of the completed property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOMPLETED(String value) {
        this.completed = value;
    }

    /**
     * Gets the value of the percentcompleted property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getPERCENTCOMPLETED() {
        return percentcompleted;
    }

    /**
     * Sets the value of the percentcompleted property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setPERCENTCOMPLETED(Long value) {
        this.percentcompleted = value;
    }

    /**
     * Gets the value of the completeddate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getCOMPLETEDDATE() {
        return completeddate;
    }

    /**
     * Sets the value of the completeddate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setCOMPLETEDDATE(DATETIME value) {
        this.completeddate = value;
    }

    /**
     * Gets the value of the notifycomplete property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getNOTIFYCOMPLETE() {
        return notifycomplete;
    }

    /**
     * Sets the value of the notifycomplete property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setNOTIFYCOMPLETE(String value) {
        this.notifycomplete = value;
    }

    /**
     * Gets the value of the notifyreadytostart property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getNOTIFYREADYTOSTART() {
        return notifyreadytostart;
    }

    /**
     * Sets the value of the notifyreadytostart property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setNOTIFYREADYTOSTART(String value) {
        this.notifyreadytostart = value;
    }

}
